Header menu logo JDeck

JDeck Namespace

Type/Module Description

Builders

Provides an in-the-box computation expression that can be used to decode JSON elements. Ideally you should use https://github.com/demystifyfp/FsToolkit.ErrorHandling instead of this as it is much more complete and would allow you to handle decoding workflows in a more robust way. However, if you don't want to take a dependency on FsToolkit.ErrorHandling, this should be just enough for you.

Codec

CollectErrorsDecoder<'TResult>

Decode

DecodeError (Module)

DecodeError (Type)

In case of failure when a type is being decoded, this type is meant to contain the relevant information about the error.

Decoder<'TResult>

Decoding

DecodingException

Encoder<'T>

Encoding

IndexedCollectErrorsDecoder<'TResult>

IndexedDecoder<'TResult>

IndexedMapCollectErrorsDecoder<'TValue>

IndexedMapDecoder<'TValue>

MapEntryEncoder<'Key, 'Value>

Type something to start searching.