Header menu logo JDeck

Decode Module

Nested modules

Modules Description

Decode

Optional

Contains a set of decoders that are not required to decode to the particular type and will not fail. These decoders will return an option type. even if the value is null or is absent from the JSON element.

Required

Contains a set of decoders that are required to decode to the particular type otherwise the decoding will fail.

VOptional

Contains a set of decoders that are not required to decode to the particular type and will not fail. These decoders will return a voption type. even if the value is null or is absent from the JSON element.

Type something to start searching.