Header menu logo JDeck

Optional Module

Contains a set of decoders that are not required to decode to the particular type and will not fail. These decoders will return an option type. even if the value is null or is absent from the JSON element.

Types

Type Description

Property

This type containes methods that are particularly useful to decode properties from JSON elements. They can be primitive properties, objects, arrays, etc.

Functions and values

Function or value Description

boolean

Full Usage: boolean

Returns: Decoder<bool option>
Returns: Decoder<bool option>

byte

Full Usage: byte

Returns: Decoder<byte option>
Returns: Decoder<byte option>

char

Full Usage: char

Returns: Decoder<char option>
Returns: Decoder<char option>

dateTime

Full Usage: dateTime

Returns: Decoder<DateTime option>
Returns: Decoder<DateTime option>

dateTimeExact format

Full Usage: dateTimeExact format

Parameters:
    format : string

Returns: Decoder<DateTime option>
format : string
Returns: Decoder<DateTime option>

dateTimeExactWith format provider style

Full Usage: dateTimeExactWith format provider style

Parameters:
Returns: Decoder<DateTime option>
format : string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTime option>

dateTimeOffset

Full Usage: dateTimeOffset

Returns: Decoder<DateTimeOffset option>
Returns: Decoder<DateTimeOffset option>

dateTimeOffsetExact format

Full Usage: dateTimeOffsetExact format

Parameters:
    format : string

Returns: Decoder<DateTimeOffset option>
format : string
Returns: Decoder<DateTimeOffset option>

dateTimeOffsetExactWith format provider style

Full Usage: dateTimeOffsetExactWith format provider style

Parameters:
Returns: Decoder<DateTimeOffset option>
format : string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTimeOffset option>

decimal

Full Usage: decimal

Returns: Decoder<decimal option>
Returns: Decoder<decimal option>

dict arg1

Full Usage: dict arg1

Parameters:
Returns: Decoder<Dictionary<string, 'TValue> option>
arg0 : Decoder<'TValue>
Returns: Decoder<Dictionary<string, 'TValue> option>

float

Full Usage: float

Returns: Decoder<float option>
Returns: Decoder<float option>

guid

Full Usage: guid

Returns: Decoder<Guid option>
Returns: Decoder<Guid option>

int

Full Usage: int

Returns: Decoder<int option>
Returns: Decoder<int option>

int16

Full Usage: int16

Returns: Decoder<int16 option>
Returns: Decoder<int16 option>

int64

Full Usage: int64

Returns: Decoder<int64 option>
Returns: Decoder<int64 option>

map arg1

Full Usage: map arg1

Parameters:
Returns: Decoder<Map<string, 'TValue> option>
arg0 : Decoder<'TValue>
Returns: Decoder<Map<string, 'TValue> option>

sbyte

Full Usage: sbyte

Returns: Decoder<sbyte option>
Returns: Decoder<sbyte option>

single

Full Usage: single

Returns: Decoder<single option>
Returns: Decoder<single option>

string

Full Usage: string

Returns: Decoder<string option>
Returns: Decoder<string option>

timeSpan

Full Usage: timeSpan

Returns: Decoder<TimeSpan option>
Returns: Decoder<TimeSpan option>

timeSpanExact format

Full Usage: timeSpanExact format

Parameters:
    format : string

Returns: Decoder<TimeSpan option>
format : string
Returns: Decoder<TimeSpan option>

timeSpanExactWith format provider style

Full Usage: timeSpanExactWith format provider style

Parameters:
Returns: Decoder<TimeSpan option>
format : string
provider : IFormatProvider
style : TimeSpanStyles
Returns: Decoder<TimeSpan option>

uint16

Full Usage: uint16

Returns: Decoder<uint16 option>
Returns: Decoder<uint16 option>

uint32

Full Usage: uint32

Returns: Decoder<uint32 option>
Returns: Decoder<uint32 option>

uint64

Full Usage: uint64

Returns: Decoder<uint64 option>
Returns: Decoder<uint64 option>

unit

Full Usage: unit

Returns: Decoder<unit option>
Returns: Decoder<unit option>

Type something to start searching.