Header menu logo JDeck

Required Module

Contains a set of decoders that are required to decode to the particular type otherwise the decoding will fail.

Types

Type Description

Property

This type containes methods that are particularly useful to decode properties from JSON elements. They can be primitive properties, objects, arrays, etc.

Functions and values

Function or value Description

boolean

Full Usage: boolean

Returns: Decoder<bool>
Returns: Decoder<bool>

byte

Full Usage: byte

Returns: Decoder<byte>
Returns: Decoder<byte>

char

Full Usage: char

Returns: Decoder<char>
Returns: Decoder<char>

dateTime

Full Usage: dateTime

Returns: Decoder<DateTime>
Returns: Decoder<DateTime>

dateTimeExact format

Full Usage: dateTimeExact format

Parameters:
    format : string

Returns: Decoder<DateTime>
format : string
Returns: Decoder<DateTime>

dateTimeExactWith format provider style

Full Usage: dateTimeExactWith format provider style

Parameters:
Returns: Decoder<DateTime>
format : string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTime>

dateTimeOffset

Full Usage: dateTimeOffset

Returns: Decoder<DateTimeOffset>
Returns: Decoder<DateTimeOffset>

dateTimeOffsetExact format

Full Usage: dateTimeOffsetExact format

Parameters:
    format : string

Returns: Decoder<DateTimeOffset>
format : string
Returns: Decoder<DateTimeOffset>

dateTimeOffsetExactWith format provider style

Full Usage: dateTimeOffsetExactWith format provider style

Parameters:
Returns: Decoder<DateTimeOffset>
format : string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTimeOffset>

decimal

Full Usage: decimal

Returns: Decoder<decimal>
Returns: Decoder<decimal>

dict arg1

Full Usage: dict arg1

Parameters:
Returns: Decoder<Dictionary<string, 'TValue>>
arg0 : Decoder<'TValue>
Returns: Decoder<Dictionary<string, 'TValue>>

float

Full Usage: float

Returns: Decoder<float>
Returns: Decoder<float>

guid

Full Usage: guid

Returns: Decoder<Guid>
Returns: Decoder<Guid>

int

Full Usage: int

Returns: Decoder<int>
Returns: Decoder<int>

int16

Full Usage: int16

Returns: Decoder<int16>
Returns: Decoder<int16>

int64

Full Usage: int64

Returns: Decoder<int64>
Returns: Decoder<int64>

map arg1

Full Usage: map arg1

Parameters:
Returns: Decoder<Map<string, 'TValue>>
arg0 : Decoder<'TValue>
Returns: Decoder<Map<string, 'TValue>>

sbyte

Full Usage: sbyte

Returns: Decoder<sbyte>
Returns: Decoder<sbyte>

single

Full Usage: single

Returns: Decoder<single>
Returns: Decoder<single>

string

Full Usage: string

Returns: Decoder<string>
Returns: Decoder<string>

timeSpan

Full Usage: timeSpan

Returns: Decoder<TimeSpan>
Returns: Decoder<TimeSpan>

timeSpanExact format

Full Usage: timeSpanExact format

Parameters:
    format : string

Returns: Decoder<TimeSpan>
format : string
Returns: Decoder<TimeSpan>

timeSpanExactWith format provider style

Full Usage: timeSpanExactWith format provider style

Parameters:
Returns: Decoder<TimeSpan>
format : string
provider : IFormatProvider
style : TimeSpanStyles
Returns: Decoder<TimeSpan>

uint16

Full Usage: uint16

Returns: Decoder<uint16>
Returns: Decoder<uint16>

uint32

Full Usage: uint32

Returns: Decoder<uint32>
Returns: Decoder<uint32>

uint64

Full Usage: uint64

Returns: Decoder<uint64>
Returns: Decoder<uint64>

unit

Full Usage: unit

Returns: Decoder<unit>
Returns: Decoder<unit>

Type something to start searching.