Header menu logo JDeck

VOptional Module

Contains a set of decoders that are not required to decode to the particular type and will not fail. These decoders will return a voption type. even if the value is null or is absent from the JSON element.

Types

Type Description

Property

This type containes methods that are particularly useful to decode properties from JSON elements. They can be primitive properties, objects, arrays, etc.

Functions and values

Function or value Description

boolean

Full Usage: boolean

Returns: Decoder<bool voption>
Returns: Decoder<bool voption>

byte

Full Usage: byte

Returns: Decoder<byte voption>
Returns: Decoder<byte voption>

char

Full Usage: char

Returns: Decoder<char voption>
Returns: Decoder<char voption>

dateTime

Full Usage: dateTime

Returns: Decoder<DateTime voption>
Returns: Decoder<DateTime voption>

dateTimeExact format

Full Usage: dateTimeExact format

Parameters:
    format : string

Returns: Decoder<DateTime voption>
format : string
Returns: Decoder<DateTime voption>

dateTimeExactWith format provider style

Full Usage: dateTimeExactWith format provider style

Parameters:
Returns: Decoder<DateTime voption>
format : string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTime voption>

dateTimeOffset

Full Usage: dateTimeOffset

Returns: Decoder<DateTimeOffset voption>
Returns: Decoder<DateTimeOffset voption>

dateTimeOffsetExact format

Full Usage: dateTimeOffsetExact format

Parameters:
    format : string

Returns: Decoder<DateTimeOffset voption>
format : string
Returns: Decoder<DateTimeOffset voption>

dateTimeOffsetExactWith format provider style

Full Usage: dateTimeOffsetExactWith format provider style

Parameters:
Returns: Decoder<DateTimeOffset voption>
format : string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTimeOffset voption>

decimal

Full Usage: decimal

Returns: Decoder<decimal voption>
Returns: Decoder<decimal voption>

dict arg1

Full Usage: dict arg1

Parameters:
Returns: Decoder<Dictionary<string, 'TValue> voption>
arg0 : Decoder<'TValue>
Returns: Decoder<Dictionary<string, 'TValue> voption>

float

Full Usage: float

Returns: Decoder<float voption>
Returns: Decoder<float voption>

guid

Full Usage: guid

Returns: Decoder<Guid voption>
Returns: Decoder<Guid voption>

int

Full Usage: int

Returns: Decoder<int voption>
Returns: Decoder<int voption>

int16

Full Usage: int16

Returns: Decoder<int16 voption>
Returns: Decoder<int16 voption>

int64

Full Usage: int64

Returns: Decoder<int64 voption>
Returns: Decoder<int64 voption>

map arg1

Full Usage: map arg1

Parameters:
Returns: Decoder<Map<string, 'TValue> voption>
arg0 : Decoder<'TValue>
Returns: Decoder<Map<string, 'TValue> voption>

sbyte

Full Usage: sbyte

Returns: Decoder<sbyte voption>
Returns: Decoder<sbyte voption>

single

Full Usage: single

Returns: Decoder<single voption>
Returns: Decoder<single voption>

string

Full Usage: string

Returns: Decoder<string voption>
Returns: Decoder<string voption>

timeSpan

Full Usage: timeSpan

Returns: Decoder<TimeSpan voption>
Returns: Decoder<TimeSpan voption>

timeSpanExact format

Full Usage: timeSpanExact format

Parameters:
    format : string

Returns: Decoder<TimeSpan voption>
format : string
Returns: Decoder<TimeSpan voption>

timeSpanExactWith format provider style

Full Usage: timeSpanExactWith format provider style

Parameters:
Returns: Decoder<TimeSpan voption>
format : string
provider : IFormatProvider
style : TimeSpanStyles
Returns: Decoder<TimeSpan voption>

uint16

Full Usage: uint16

Returns: Decoder<uint16 voption>
Returns: Decoder<uint16 voption>

uint32

Full Usage: uint32

Returns: Decoder<uint32 voption>
Returns: Decoder<uint32 voption>

uint64

Full Usage: uint64

Returns: Decoder<uint64 voption>
Returns: Decoder<uint64 voption>

unit

Full Usage: unit

Returns: Decoder<unit voption>
Returns: Decoder<unit voption>

Type something to start searching.