Header menu logo JDeck

DecodeError Type

In case of failure when a type is being decoded, this type is meant to contain the relevant information about the error.

Record fields

Record Field Description

exn

Full Usage: exn

Field type: exn option
Field type: exn option

index

Full Usage: index

Field type: int option
Field type: int option

kind

Full Usage: kind

Field type: JsonValueKind
Field type: JsonValueKind

message

Full Usage: message

Field type: string
Field type: string

property

Full Usage: property

Field type: string option
Field type: string option

rawValue

Full Usage: rawValue

Field type: string
Field type: string

targetType

Full Usage: targetType

Field type: Type
Field type: Type

value

Full Usage: value

Field type: JsonElement

The value that was being decoded when the error occurred.

Please be sure to "clone" this value by calling `JsonElement.Clone()` before using it. otherwise you could run into the issue of trying to access an already disposed value.

Field type: JsonElement

Type something to start searching.