Provides an in-the-box computation expression that can be used to decode JSON elements.
Ideally you should use https://github.com/demystifyfp/FsToolkit.ErrorHandling instead of this as it is much more complete
and would allow you to handle decoding workflows in a more robust way.
However, if you don't want to take a dependency on FsToolkit.ErrorHandling, this should be just enough for you.