Contains a set of decoders that are not required to decode to the particular type and will not fail.
These decoders will return an option type. even if the value is null or is absent from the JSON element.
Contains a set of decoders that are not required to decode to the particular type and will not fail.
These decoders will return a voption type. even if the value is null or is absent from the JSON element.