Required Module
Contains a set of decoders that are required to decode to the particular type otherwise the decoding will fail.
Types
| Type | Description |
Functions and values
| Function or value | Description |
|
|
|
|
|
|
|
|
Full Usage:
dateTimeExactWith format provider style
Parameters:
string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTime>
|
|
|
|
|
|
Full Usage:
dateTimeOffsetExactWith format provider style
Parameters:
string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTimeOffset>
|
|
|
|
Full Usage:
dict arg1
Parameters:
Decoder<'TValue>
Returns: Decoder<Dictionary<string, 'TValue>>
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
timeSpanExactWith format provider style
Parameters:
string
provider : IFormatProvider
style : TimeSpanStyles
Returns: Decoder<TimeSpan>
|
|
|
|
|
|
|
|
|
JDeck