VOptional Module
Contains a set of decoders that are not required to decode to the particular type and will not fail. These decoders will return a voption type. even if the value is null or is absent from the JSON element.
Types
| Type | Description |
Functions and values
| Function or value | Description |
|
|
|
|
|
|
|
|
Full Usage:
dateTimeExactWith format provider style
Parameters:
string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTime voption>
|
|
|
|
Full Usage:
dateTimeOffsetExact format
Parameters:
string
Returns: Decoder<DateTimeOffset voption>
|
|
Full Usage:
dateTimeOffsetExactWith format provider style
Parameters:
string
provider : IFormatProvider
style : DateTimeStyles
Returns: Decoder<DateTimeOffset voption>
|
|
|
|
Full Usage:
dict arg1
Parameters:
Decoder<'TValue>
Returns: Decoder<Dictionary<string, 'TValue> voption>
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
timeSpanExactWith format provider style
Parameters:
string
provider : IFormatProvider
style : TimeSpanStyles
Returns: Decoder<TimeSpan voption>
|
|
|
|
|
|
|
|
|
JDeck