DecodeError Type
In case of failure when a type is being decoded, this type is meant to contain the relevant information about the error.
Record fields
| Record Field | Description |
Full Usage:
exn
Field type: exn option
|
|
Full Usage:
index
Field type: int option
|
|
|
|
Full Usage:
message
Field type: string
|
|
Full Usage:
property
Field type: string option
|
|
Full Usage:
rawValue
Field type: string
|
|
|
|
|
Please be sure to "clone" this value by calling `JsonElement.Clone()` before using it. otherwise you could run into the issue of trying to access an already disposed value.
|
JDeck