Decoding Type
Static members
| Static member | Description |
Full Usage:
Decoding.auto (json, options, ?docOptions)
Parameters:
Stream
-
options : JsonSerializerOptions
-
?docOptions : JsonDocumentOptions
-
Returns: Task<Result<'TResult, DecodeError>>
Modifiers: inline Type parameters: 'TResult |
Attempts to decode a JSON stream using a JsonDocument instance. Without any decoder, works just like `JsonSerializer.Deserialize(json)`. You can pass JsonSerializerOptions to customize the deserialization process and even include your decoders.
|
Full Usage:
Decoding.auto (json, ?docOptions)
Parameters:
Stream
-
?docOptions : JsonDocumentOptions
-
Returns: Task<Result<'TResult, DecodeError>>
Modifiers: inline Type parameters: 'TResult |
Attempts to decode a JSON stream using a JsonDocument instance. Without any decoder, works just like `JsonSerializer.Deserialize(json)`.
|
Full Usage:
Decoding.auto (json, options, ?docOptions)
Parameters:
byte array
-
options : JsonSerializerOptions
-
?docOptions : JsonDocumentOptions
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
Attempts to decode a JSON byte array using a JsonDocument instance. Without any decoder, works just like `JsonSerializer.Deserialize(json)`. You can pass JsonSerializerOptions to customize the deserialization process and even include your decoders.
|
Full Usage:
Decoding.auto (json, ?docOptions)
Parameters:
byte array
-
?docOptions : JsonDocumentOptions
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
Attempts to decode a JSON byte array using a JsonDocument instance. Without any decoder, works just like `JsonSerializer.Deserialize(json)`.
|
Full Usage:
Decoding.auto (json, options, ?docOptions)
Parameters:
string
-
options : JsonSerializerOptions
-
?docOptions : JsonDocumentOptions
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
Attempts to decode a JSON string using a JsonDocument instance. Without any decoder, works just like `JsonSerializer.Deserialize(json)`. You can pass JsonSerializerOptions to customize the deserialization process and even include your decoders.
|
Full Usage:
Decoding.auto (json, ?docOptions)
Parameters:
string
-
?docOptions : JsonDocumentOptions
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
Attempts to decode a JSON string using a JsonDocument instance. Without any decoder, works just like `JsonSerializer.Deserialize(json)`.
|
Full Usage:
Decoding.fromBytes (value, decoder)
Parameters:
byte array
-
decoder : Decoder<'TResult>
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
|
Full Usage:
Decoding.fromBytes (value, options, decoder)
Parameters:
byte array
-
options : JsonDocumentOptions
-
decoder : JsonElement -> 'TResult
-
Returns: 'TResult
Modifiers: inline Type parameters: 'TResult |
|
Full Usage:
Decoding.fromBytesCol (value, decoder)
Parameters:
byte array
-
decoder : CollectErrorsDecoder<'TResult>
-
Returns: Result<'TResult, DecodeError list>
Modifiers: inline Type parameters: 'TResult |
This method will take a result that collects all the errors that occur during the decoding process.
|
Full Usage:
Decoding.fromBytesCol (value, options, decoder)
Parameters:
byte array
-
options : JsonDocumentOptions
-
decoder : CollectErrorsDecoder<'TResult>
-
Returns: Result<'TResult, DecodeError list>
Modifiers: inline Type parameters: 'TResult |
This method will take a result that collects all the errors that occur during the decoding process.
|
Full Usage:
Decoding.fromStream (value, decoder)
Parameters: Returns: Task<Result<'TResult, DecodeError>>
Modifiers: inline Type parameters: 'TResult |
|
Full Usage:
Decoding.fromStream (value, options, decoder)
Parameters:
Stream
-
options : JsonDocumentOptions
-
decoder : JsonElement -> 'TResult
-
Returns: Task<'TResult>
Modifiers: inline Type parameters: 'TResult |
|
Full Usage:
Decoding.fromStreamCol (value, decoder)
Parameters:
Stream
-
decoder : CollectErrorsDecoder<'TResult>
-
Returns: Task<Result<'TResult, DecodeError list>>
Modifiers: inline Type parameters: 'TResult |
This method will take a result that collects all the errors that occur during the decoding process.
|
Full Usage:
Decoding.fromStreamCol (value, options, decoder)
Parameters:
Stream
-
options : JsonDocumentOptions
-
decoder : CollectErrorsDecoder<'TResult>
-
Returns: Task<Result<'TResult, DecodeError list>>
Modifiers: inline Type parameters: 'TResult |
This method will take a result that collects all the errors that occur during the decoding process.
|
Full Usage:
Decoding.fromString (value, decoder)
Parameters:
string
-
decoder : Decoder<'TResult>
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
|
Full Usage:
Decoding.fromString (value, options, decoder)
Parameters:
string
-
options : JsonDocumentOptions
-
decoder : Decoder<'TResult>
-
Returns: Result<'TResult, DecodeError>
Modifiers: inline Type parameters: 'TResult |
|
Full Usage:
Decoding.fromStringCol (value, decoder)
Parameters:
string
-
decoder : CollectErrorsDecoder<'TResult>
-
Returns: Result<'TResult, DecodeError list>
Modifiers: inline Type parameters: 'TResult |
This method will take a result that collects all the errors that occur during the decoding process.
|
Full Usage:
Decoding.fromStringCol (value, options, decoder)
Parameters:
string
-
options : JsonDocumentOptions
-
decoder : CollectErrorsDecoder<'TResult>
-
Returns: Result<'TResult, DecodeError list>
Modifiers: inline Type parameters: 'TResult |
This method will take a result that collects all the errors that occur during the decoding process.
|
JDeck